==> haskell-tasty-expected-failure-0.11.1.1-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.1.1
id: tasty-expected-failure-0.11.1.1-EK0mQ0zWM68zI4iM2lpaw
key: tasty-expected-failure-0.11.1.1-EK0mQ0zWM68zI4iM2lpaw
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
author: Joachim Breitner
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
abi: 0d5b68e6fa4aada88cbbef0136c71f7f
exposed: True
exposed-modules:
    Test.Tasty.ExpectedFailure
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-expected-failure-0.11.1.1
hs-libraries: HStasty-expected-failure-0.11.1.1-EK0mQ0zWM68zI4iM2lpaw
depends:
    base-4.12.0.0 tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2-L0qrhWDKU2n6IIJu4C6GSU
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.11.1.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.1.1
id: tasty-expected-failure-0.11.1.1-6K2UE2FltfMGlWfpcKdEDg
key: tasty-expected-failure-0.11.1.1-6K2UE2FltfMGlWfpcKdEDg
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
author: Joachim Breitner
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
abi: ca4502c5d1c4001c3f5db430f8314237
exposed: True
exposed-modules:
    Test.Tasty.ExpectedFailure
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-expected-failure-0.11.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-expected-failure-0.11.1.1
hs-libraries: HStasty-expected-failure-0.11.1.1-6K2UE2FltfMGlWfpcKdEDg
depends:
    base-4.12.0.0 tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-AUVOTgx4uuy2lCe0MDaZEJ
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
